@@ -8,6 +8,3 @@ isort:skip_file
 from .train import TrainFuture as WorkflowTrainFuture
 from .predict import PredictionResultFuture as WorkflowPredictionResultFuture
 from .design import DesignFuture as WorkflowDesignFuture
-
-# old poet
-from .poet import PoetGenerateFuture, PoetScoreFuture, PoetSingleSiteFuture
